==> nextcloud-13.0.2.tar.bz2: nextcloud/apps/files_texteditor/l10n/is.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "er að vista ...",
    "saved!" : "vistað!",
    "failed!" : "mistókst!",
    "Saved" : "Vistað",
    "There was a problem saving your changes. Click to resume editing." : "Það kom upp vandamál við að vista breytingarnar þínar. Smelltu til að halda ritun áfram.",
    "An error occurred!" : "Villa kom upp!",
    "Edit" : "Breyta",
    "Mixed" : "Blandað",
    "Preview" : "Forskoðun",
    "New text file" : "Ný textaskrá",
    "New text file.txt" : "Ný textaskrá.txt",
    "You can not open a folder" : "Þú getur ekki opnað möppu",
    "This file is too big to be opened. Please download the file instead." : "Þessi skrá er of stór til að opna hana hér. Halaðu henni niður í staðinn.",
    "Cannot read the file." : "Get ekki lesið skrána.",
    "Invalid file path supplied." : "Ógild skráarslóð.",
    "The file is locked." : "Skráin er læst.",
    "An internal server error occurred." : "Innri villa kom upp.",
    "You can not write to a folder" : "Þú getur ekki skrifað í möppu",
    "Cannot save file as it has been modified since opening" : "Get ekki vistað skrána þar sem henni hefur verið breytt síðan hún var opnuð",
    "Insufficient permissions" : "Ekki næg réttindi",
    "File path not supplied" : "Skrá slóð fylgir ekki",
    "File mtime not supplied" : "mtime skrá fylgir ekki",
    "Share not found" : "Sameign fannst ekki",
    "You are not authorized to open this share" : "Þú hefur ekki heimild til að opna þessa sameign",
    "Invalid range request" : "Ógild fyrirspurn um gagnasvið",
    "Text editor" : "Textaritill"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-16.0.9.tar.bz2: nextcloud/apps/files_texteditor/l10n/is.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "er að vista ...",
    "saved!" : "vistað!",
    "failed!" : "mistókst!",
    "Saved" : "Vistað",
    "There was a problem saving your changes. Click to resume editing." : "Það kom upp vandamál við að vista breytingarnar þínar. Smelltu til að halda ritun áfram.",
    "Edit in plain text editor" : "Breyta með hreinum textaritli",
    "An error occurred!" : "Villa kom upp!",
    "Edit" : "Breyta",
    "Mixed" : "Blandað",
    "Preview" : "Forskoðun",
    "New text file" : "Ný textaskrá",
    "New text file.txt" : "Ný textaskrá.txt",
    "You can not open a folder" : "Þú getur ekki opnað möppu",
    "This file is too big to be opened. Please download the file instead." : "Þessi skrá er of stór til að opna hana hér. Halaðu henni niður í staðinn.",
    "Cannot read the file." : "Get ekki lesið skrána.",
    "Invalid file path supplied." : "Ógild skráarslóð.",
    "The file is locked." : "Skráin er læst.",
    "An internal server error occurred." : "Innri villa kom upp.",
    "You can not write to a folder" : "Þú getur ekki skrifað í möppu",
    "Cannot save file as it has been modified since opening" : "Get ekki vistað skrána þar sem henni hefur verið breytt síðan hún var opnuð",
    "Could not write to file." : "Ekki tókst að skrifa í skrá.",
    "Insufficient permissions" : "Ekki næg réttindi",
    "File path not supplied" : "Skrá slóð fylgir ekki",
    "File mtime not supplied" : "mtime skrá fylgir ekki",
    "Share not found" : "Sameign fannst ekki",
    "You are not authorized to open this share" : "Þú hefur ekki heimild til að opna þessa sameign",
    "Invalid range request" : "Ógild fyrirspurn um gagnasvið",
    "Plain text editor" : "Ritill fyrir hreinan texta",
    "Text editor" : "Textaritill"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
